@@ -14,6 +14,8 @@ class RawUser(BaseModel):
     record_uid: str
     schools: Sequence[str]
     source_uid: str
-    synonyms: Dict[str, Optional[str]]  # idBrokerPseudonym0023: 3ecc16f6-8f02-45b1-b27a-a2e76859f83f
+    synonyms: Dict[
+        str, Optional[str]
+    ]  # idBrokerPseudonym0023: 3ecc16f6-8f02-45b1-b27a-a2e76859f83f
     ucsschool_roles: Sequence[str]
     username: str
