@@ -34,7 +34,18 @@ import datetime
 import re
 import time
 from functools import lru_cache
-from typing import Awaitable, Callable, Dict, Iterable, Iterator, List, Optional, Tuple, TypeVar, Union
+from typing import (
+    Awaitable,
+    Callable,
+    Dict,
+    Iterable,
+    Iterator,
+    List,
+    Optional,
+    Tuple,
+    TypeVar,
+    Union,
+)
 
 import click
 from ldap3 import Entry
@@ -64,12 +75,15 @@ try:
         User,
         WorkGroup,
     )
+    from .utils import get_configured_schools, school_in_configured_schools
 except ImportError:
     # works on the cli in ID Connector Docker container
     # make `idbroker` package importable
     import sys
 
-    sys.path.append("/var/lib/univention-appcenter/apps/ucsschool-id-connector/conf/plugins/packages")
+    sys.path.append(
+        "/var/lib/univention-appcenter/apps/ucsschool-id-connector/conf/plugins/packages"
+    )
 
     from idbroker.config_utils import CONFIG_PATH, read_id_broker_config
     from idbroker.id_broker_client import (
@@ -87,11 +101,21 @@ except ImportError:
         User,
         WorkGroup,
     )
+    from idbroker.utils import get_configured_schools, school_in_configured_schools
 
 
 SCHOOL_ATTRS = ["entryUUID", "ou", "displayName"]
 GROUP_ATTRS = ["entryUUID", "cn", "description", "uniqueMember"]
-USER_ATTRS = ["entryUUID", "uid", "givenName", "sn", "memberOf", "ucsschoolRole"]
+USER_ATTRS = [
+    "entryUUID",
+    "uid",
+    "givenName",
+    "sn",
+    "memberOf",
+    "ucsschoolRole",
+    "ucsschoolLegalGuardian",
+    "ucsschoolLegalWard",
+]
 SCHOOL_CLASS_DN_PATTERN = re.compile(
     r"^cn=(?P<cn>.+?),cn=klassen,cn=schueler,cn=groups,ou=(?P<ou>.+?),dc=.+$"
 )
@@ -138,28 +162,42 @@ def verify_users(
     school_authority_name: str,
     fix: bool,
 ) -> None:
-    """Verify users: '(&(|(ucsschoolRole=teacher:*)(ucsschoolRole=student:*))(LDAP_FILTER))'"""
+    """
+    Verify users:
+    '(&(|(ucsschoolRole=teacher:*)(ucsschoolRole=student:*)(ucsschoolRole=legal_guardian:*))(LDAP_FILTER))'
+    """
+    role_filter = "(|(ucsschoolRole=teacher:*)(ucsschoolRole=student:*)(ucsschoolRole=legal_guardian:*))"
     if ldap_filter:
-        ldap_filter = f"(&(|(ucsschoolRole=teacher:*)(ucsschoolRole=student:*))({ldap_filter}))"
+        ldap_filter = f"(&{role_filter}({ldap_filter}))"
     else:
-        ldap_filter = "(|(ucsschoolRole=teacher:*)(ucsschoolRole=student:*))"
+        ldap_filter = role_filter
     try:
-        ldap_objects: List[Entry] = asyncio.run(get_ldap_objects(ldap_filter, USER_ATTRS))
+        ldap_objects: List[Entry] = asyncio.run(
+            get_ldap_objects(ldap_filter, USER_ATTRS)
+        )
     except LDAPInvalidFilterError:
         raise click.ClickException(
             f"Your LDAP filter is invalid, the complete filter that was used: {ldap_filter}"
         )
     ldap_objects.sort(key=lambda obj: obj.entry_dn)
-    user_objects = [ldap_object_to_user(o) for o in ldap_objects]
     school_authority = read_id_broker_config(
         config_path=CONFIG_PATH, school_authority_name=school_authority_name
     )
+    configured_schools = get_configured_schools(school_authority)
+    user_objects = [
+        user
+        for user in asyncio.run(ldap_users_to_id_broker_users(ldap_objects))
+        if any(
+            school_in_configured_schools(school.lower(), configured_schools)
+            for school in user.context.keys()
+        )
+    ]
     id_broker_user = IDBrokerUser(school_authority, "id_broker")
     asyncio.run(
         get_remote_objects_and_compare(
             user_objects,
             id_broker_user,
-            Compare(no_classes=no_classes, fix=fix).compare_user,
+            Compare(school_authority, no_classes=no_classes, fix=fix).compare_user,
             parallelism,
             fix=fix,
         )
@@ -187,23 +225,31 @@ def verify_school_classes(
     else:
         ldap_filter = "(ucsschoolRole=school_class:*)"
     try:
-        ldap_objects: List[Entry] = asyncio.run(get_ldap_objects(ldap_filter, GROUP_ATTRS))
+        ldap_objects: List[Entry] = asyncio.run(
+            get_ldap_objects(ldap_filter, GROUP_ATTRS)
+        )
     except LDAPInvalidFilterError:
         raise click.ClickException(
             f"Your LDAP filter is invalid, the complete filter that was used: {ldap_filter}"
         )
     ldap_objects.sort(key=lambda obj: obj.entry_dn)
-    school_class_objects = [ldap_object_to_school_class(o) for o in ldap_objects]
-    school_class_objects = [o for o in school_class_objects if o is not None]
     school_authority = read_id_broker_config(
         config_path=CONFIG_PATH, school_authority_name=school_authority_name
     )
+    configured_schools = get_configured_schools(school_authority)
+    school_class_objects = [ldap_object_to_school_class(o) for o in ldap_objects]
+    school_class_objects = [
+        o
+        for o in school_class_objects
+        if o is not None
+        and school_in_configured_schools(o.school.lower(), configured_schools)
+    ]
     id_broker_school_class = IDBrokerSchoolClass(school_authority, "id_broker")
     asyncio.run(
         get_remote_objects_and_compare(
             school_class_objects,
             id_broker_school_class,
-            Compare(fix=fix).compare_school_group,
+            Compare(school_authority, fix=fix).compare_school_group,
             parallelism,
         )
     )
@@ -221,28 +267,41 @@ def verify_school_classes(
 )
 @click.option("-a", "--school_authority_name", required=True, type=str)
 @click.option("--fix", is_flag=True, help="Queue objects that failed for resync")
-def verify_workgroups(ldap_filter: str, parallelism: int, school_authority_name: str, fix: bool) -> None:
+def verify_workgroups(
+    ldap_filter: str, parallelism: int, school_authority_name: str, fix: bool
+) -> None:
     """Verify work groups: '(&(ucsschoolRole=workgroups:*)(LDAP_FILTER))'"""
     if ldap_filter:
         ldap_filter = f"(&(ucsschoolRole=workgroup:*)({ldap_filter}))"
     else:
         ldap_filter = "(ucsschoolRole=workgroup:*)"
     try:
-        ldap_objects: List[Entry] = asyncio.run(get_ldap_objects(ldap_filter, GROUP_ATTRS))
+        ldap_objects: List[Entry] = asyncio.run(
+            get_ldap_objects(ldap_filter, GROUP_ATTRS)
+        )
     except LDAPInvalidFilterError:
         raise click.ClickException(
             f"Your LDAP filter is invalid, the complete filter that was used: {ldap_filter}"
         )
     ldap_objects.sort(key=lambda obj: obj.entry_dn)
-    _workgroup_objects = [ldap_object_to_workgroup(o) for o in ldap_objects]
-    workgroup_objects = [o for o in _workgroup_objects if o is not None]
     school_authority = read_id_broker_config(
         config_path=CONFIG_PATH, school_authority_name=school_authority_name
     )
+    configured_schools = get_configured_schools(school_authority)
+    _workgroup_objects = [ldap_object_to_workgroup(o) for o in ldap_objects]
+    workgroup_objects = [
+        o
+        for o in _workgroup_objects
+        if o is not None
+        and school_in_configured_schools(o.school.lower(), configured_schools)
+    ]
     id_broker_workgroup = IDBrokerWorkGroup(school_authority, "id_broker")
     asyncio.run(
         get_remote_objects_and_compare(
-            workgroup_objects, id_broker_workgroup, Compare(fix=fix).compare_school_group, parallelism
+            workgroup_objects,
+            id_broker_workgroup,
+            Compare(school_authority, fix=fix).compare_school_group,
+            parallelism,
         )
     )
 
@@ -259,28 +318,41 @@ def verify_workgroups(ldap_filter: str, parallelism: int, school_authority_name:
 )
 @click.option("-a", "--school_authority_name", required=True, type=str)
 @click.option("--fix", is_flag=True, help="Queue objects that failed for resync")
-def verify_schools(ldap_filter: str, parallelism: int, school_authority_name: str, fix: bool) -> None:
+def verify_schools(
+    ldap_filter: str, parallelism: int, school_authority_name: str, fix: bool
+) -> None:
     """Verify schools: '(&(ucsschoolRole=school:*)(LDAP_FILTER))'"""
     if ldap_filter:
         ldap_filter = f"(&(ucsschoolRole=school:*)({ldap_filter}))"
     else:
         ldap_filter = "(ucsschoolRole=school:*)"
     try:
-        ldap_objects: List[Entry] = asyncio.run(get_ldap_objects(ldap_filter, SCHOOL_ATTRS))
+        ldap_objects: List[Entry] = asyncio.run(
+            get_ldap_objects(ldap_filter, SCHOOL_ATTRS)
+        )
     except LDAPInvalidFilterError:
         raise click.ClickException(
             f"Your LDAP filter is invalid, the complete filter that was used: {ldap_filter}"
         )
 
     ldap_objects.sort(key=lambda obj: obj.entry_dn)
-    school_objects = [ldap_object_to_school(o) for o in ldap_objects]
     school_authority = read_id_broker_config(
         config_path=CONFIG_PATH, school_authority_name=school_authority_name
     )
+    configured_schools = get_configured_schools(school_authority)
+    school_objects = [ldap_object_to_school(o) for o in ldap_objects]
+    school_objects = [
+        s
+        for s in school_objects
+        if school_in_configured_schools(s.name.lower(), configured_schools)
+    ]
     id_broker_school = IDBrokerSchool(school_authority, "id_broker")
     asyncio.run(
         get_remote_objects_and_compare(
-            school_objects, id_broker_school, Compare(fix=fix).compare_school, parallelism
+            school_objects,
+            id_broker_school,
+            Compare(school_authority, fix=fix).compare_school,
+            parallelism,
         )
     )
 
@@ -308,13 +380,20 @@ def role_split(ucsschool_role: str) -> Tuple[str, str, str]:
 
 async def dn_to_id(dn: str) -> str:
     if dn not in _dn_to_id_cache:
-        results = await ldap_access().search(base=dn, filter_s="(cn=*)", attributes="entryUUID")
+        results = await ldap_access().search(
+            base=dn, filter_s="(cn=*)", attributes="entryUUID"
+        )
         if len(results) != 1:
             raise ValueError(f"Cannot find object in LDAP: {dn!r}")
         _dn_to_id_cache[dn] = results[0].entryUUID.value
     return _dn_to_id_cache[dn]
 
 
+async def ldap_users_to_id_broker_users(ldap_objects: List[Entry]) -> List[User]:
+    user_objects = [await ldap_object_to_user(o) for o in ldap_objects]
+    return user_objects
+
+
 def ldap_object_to_school(ldap_object: Entry) -> School:
     return School(
         id=ldap_object.entryUUID.value,
@@ -409,12 +488,13 @@ def ldap_object_to_workgroup(ldap_object: Entry) -> Optional[WorkGroup]:
         return None
 
 
-def ldap_object_to_user(ldap_object: Entry) -> User:
+async def ldap_object_to_user(ldap_object: Entry) -> User:
     if isinstance(ldap_object.ucsschoolRole.value, str):
         ucsschool_roles = [ldap_object.ucsschoolRole.value]
     elif not ldap_object.ucsschoolRole.value:
         click.secho(
-            f"{dt_str()} User {ldap_object.uid.value!r} has empty ucsschoolRole attribute.", fg="red"
+            f"{dt_str()} User {ldap_object.uid.value!r} has empty ucsschoolRole attribute.",
+            fg="red",
         )
         ucsschool_roles = []
     else:
@@ -425,7 +505,8 @@ def ldap_object_to_user(ldap_object: Entry) -> User:
             continue
         if role == "school_admin":
             click.secho(
-                f"{dt_str()} Ignoring 'school_admin' role of user {ldap_object.uid.value!r}.", fg="white"
+                f"{dt_str()} Ignoring 'school_admin' role of user {ldap_object.uid.value!r}.",
+                fg="white",
             )
             continue
         if school in context:
@@ -485,11 +566,28 @@ def ldap_object_to_user(ldap_object: Entry) -> User:
                     f"school {school!r} which is missing in their ucsschoolRole attribute.",
                     fg="red",
                 )
+    legal_guardians_dns = ldap_object.ucsschoolLegalGuardian.value
+    legal_wards_dns = ldap_object.ucsschoolLegalWard.value
+    legal_guardians_dns = (
+        [legal_guardians_dns]
+        if isinstance(legal_guardians_dns, str)
+        else legal_guardians_dns
+    )
+    legal_wards_dns = (
+        [legal_wards_dns] if isinstance(legal_wards_dns, str) else legal_wards_dns
+    )
+
     return User(
         id=ldap_object.entryUUID.value,
         first_name=ldap_object.givenName.value or "N/A",
         last_name=ldap_object.sn.value or "N/A",
         user_name=ldap_object.uid.value,
+        legal_guardians=[await dn_to_id(dn) for dn in legal_guardians_dns]
+        if legal_guardians_dns
+        else [],
+        legal_wards=[await dn_to_id(dn) for dn in legal_wards_dns]
+        if legal_wards_dns
+        else [],
         context=context,
     )
 
@@ -497,7 +595,9 @@ def ldap_object_to_user(ldap_object: Entry) -> User:
 def get_name(obj: IDBrokerObject) -> str:
     name = obj.user_name if isinstance(obj, User) else obj.name
     name = (
-        f"{obj.school}-{name}" if (isinstance(obj, SchoolClass) or isinstance(obj, WorkGroup)) else name
+        f"{obj.school}-{name}"
+        if (isinstance(obj, SchoolClass) or isinstance(obj, WorkGroup))
+        else name
     )
     return f"{obj.__class__.__name__}({name!r} | {obj.id})"
 
@@ -510,22 +610,23 @@ def _empty_classes(context: ContextDictType) -> ContextDictType:
 
 
 class Compare:
-    def __init__(self, no_classes: bool = False, fix: bool = False):
+    def __init__(self, school_authority, no_classes: bool = False, fix: bool = False):
+        self.school_authority = school_authority
         self.no_classes = no_classes
         self.fix = fix
         self.userScheduler = UserScheduler()
         self.groupScheduler = GroupScheduler()
         self.schoolScheduler = SchoolScheduler()
+        self.school_authority = school_authority
 
     async def compare_school(self, local: School, remote: Optional[School]) -> str:
         if not remote:
             if self.fix:
                 await self.schoolScheduler.queue_school(local.name)
-                return f"FIX  : {get_name(local)} local={local.dict()!r} remote={remote}"
+                return (
+                    f"FIX  : {get_name(local)} local={local.dict()!r} remote={remote}"
+                )
             return f"FAIL : {get_name(local)}: NOT FOUND on ID Broker server."
-        if remote.display_name.startswith("Traeger"):
-            # error in test data, not in production
-            remote.display_name = remote.display_name[len("TraegerX:") :]
         if local == remote:
             return f"OK   : {get_name(local)}"
         else:
@@ -535,12 +636,16 @@ class Compare:
             return f"FAIL : {get_name(local)} local={local.dict()!r} remote={remote.dict()!r}"
 
     async def compare_school_group(
-        self, local: Union[SchoolClass, WorkGroup], remote: Optional[Union[SchoolClass, WorkGroup]]
+        self,
+        local: Union[SchoolClass, WorkGroup],
+        remote: Optional[Union[SchoolClass, WorkGroup]],
     ) -> str:
         if not remote:
             if self.fix:
                 await self.groupScheduler.queue_group(f"{local.school}-{local.name}")
-                return f"FIX  : {get_name(local)} local={local.dict()!r} remote={remote}"
+                return (
+                    f"FIX  : {get_name(local)} local={local.dict()!r} remote={remote}"
+                )
             return f"FAIL : {get_name(local)}: NOT FOUND on ID Broker server."
         local_ori_name = local.name
         local_ori_members = local.members.copy()
@@ -551,7 +656,8 @@ class Compare:
                 local.members.append(await dn_to_id(dn))
             except ValueError as exc:
                 click.secho(
-                    f"{dt_str()} Resolving member of SchoolClass {local.name!r}: {exc!s}", fg="red"
+                    f"{dt_str()} Resolving member of SchoolClass {local.name!r}: {exc!s}",
+                    fg="red",
                 )
         t1 = time.time()
         t_diff = t1 - t0
@@ -574,13 +680,23 @@ class Compare:
         if not remote:
             if self.fix:
                 await self.userScheduler.queue_user(local.user_name)
-                return f"FIX  : {get_name(local)} local={local.dict()!r} remote={remote}"
+                return (
+                    f"FIX  : {get_name(local)} local={local.dict()!r} remote={remote}"
+                )
             return f"FAIL : {get_name(local)}: NOT FOUND on ID Broker server."
         # ignore classes, e.g initial mode
         if self.no_classes:
             local.context = _empty_classes(local.context)
             remote.context = _empty_classes(remote.context)
 
+        # ignore local context of schools that should not be synced
+        configured_schools = get_configured_schools(self.school_authority)
+        for context_school in [str(s) for s in local.context.keys()]:
+            if not school_in_configured_schools(
+                context_school.lower(), configured_schools
+            ):
+                del local.context[context_school]
+
         if local == remote:
             return f"OK   : {get_name(local)}"
         else:
@@ -609,7 +725,9 @@ async def get_remote_objects_and_compare(
     for local_object_list in split_list(local_objects, parallelism):
         partial_results = await asyncio.gather(
             *[
-                get_remote_object_and_compare(local_object, client, compare_func, fix=fix)
+                get_remote_object_and_compare(
+                    local_object, client, compare_func, fix=fix
+                )
                 for local_object in local_object_list
             ]
         )
@@ -618,7 +736,7 @@ async def get_remote_objects_and_compare(
     t1 = time.time()
     click.secho(
         f"{dt_str()} Retrieved and compared {len(local_objects)} objects (parallelism: {parallelism}) "
-        f"in {t1 - t0:.2f} seconds ({len(local_objects)/(t1 - t0):.2f}/s).",
+        f"in {t1 - t0:.2f} seconds ({len(local_objects) / (t1 - t0):.2f}/s).",
         fg="white",
     )
     return results
@@ -631,6 +749,7 @@ async def get_remote_object_and_compare(
     fix=False,
 ) -> str:
     name = get_name(local_obj)
+
     click.secho(f"{dt_str()} Fetching {name} from ID Broker...", fg="white")
     try:
         remote_obj = await client.get(local_obj.id)
@@ -660,5 +779,4 @@ def print_results(results: Iterable[Union[str, Exception]]) -> None:
 
 
 if __name__ == "__main__":
-
     cli()
