@@ -114,7 +114,9 @@ def id_broker_fqdn(http_request, id_broker_ip, docker_hostname) -> str:
 
 
 @pytest.fixture(scope="session")
-def id_broker_fqdn_provisioning(http_request, id_broker_ip_provisioning, docker_hostname) -> str:
+def id_broker_fqdn_provisioning(
+    http_request, id_broker_ip_provisioning, docker_hostname
+) -> str:
     return _id_broker_fqdn(http_request, id_broker_ip_provisioning, docker_hostname)
 
 
@@ -169,17 +171,23 @@ def get_id_broker_school_auth():
 
 
 @pytest.fixture(scope="session")
-def id_broker_school_auth_conf(temp_clear_dir, school_auth_config_id_broker) -> Dict[str, Any]:
+def id_broker_school_auth_conf(
+    temp_clear_dir, school_auth_config_id_broker
+) -> Dict[str, Any]:
     s_a_name, password = get_id_broker_school_auth()
     # save existing school authority configurations
     temp_clear_dir(
-        Path("/var/lib/univention-appcenter/apps/ucsschool-id-connector/conf/school_authorities/")
+        Path(
+            "/var/lib/univention-appcenter/apps/ucsschool-id-connector/conf/school_authorities/"
+        )
     )
     yield school_auth_config_id_broker(s_a_name, password)
 
 
 @pytest_asyncio.fixture()
-def set_school_authority_on_id_connector(id_broker_school_auth_conf, make_school_authority):
+def set_school_authority_on_id_connector(
+    id_broker_school_auth_conf, make_school_authority
+):
     async def _func(schools, active=True):
         id_broker_school_auth_conf["plugin_configs"]["id_broker"]["schools"] = schools
         id_broker_school_auth_conf["active"] = active
@@ -237,7 +245,13 @@ def delete_school_on_host(docker_hostname: str, http_request):
                 f"https://Administrator:univention@{docker_hostname}/univention/udm/container/ou/",
                 school_dn,
             )
-            http_request("delete", url, verify=False, headers=req_headers, expected_statuses=(204,))
+            http_request(
+                "delete",
+                url,
+                verify=False,
+                headers=req_headers,
+                expected_statuses=(204,),
+            )
 
     return _func
 
@@ -264,14 +278,18 @@ def kelvin_user_object(docker_hostname, kelvin_session, random_name, source_uid)
         last_name = fake.last_name()
         return User(
             name=kwargs.get("name", f"test.{first_name[:5]}.{last_name}"[:15]),
-            birthday=kwargs.get("birthday", fake.date_of_birth(minimum_age=6, maximum_age=67)),
+            birthday=kwargs.get(
+                "birthday", fake.date_of_birth(minimum_age=6, maximum_age=67)
+            ),
             expiration_date=kwargs.get(
                 "expiration_date", fake.date_between(start_date="+1y", end_date="+10y")
             ),
             disabled=kwargs.get("disabled", False),
             firstname=kwargs.get("firstname", first_name),
             lastname=kwargs.get("lastname", last_name),
-            password=kwargs.get("password", fake.password(length=15, special_chars=False)),
+            password=kwargs.get(
+                "password", fake.password(length=15, special_chars=False)
+            ),
             record_uid=kwargs.get(
                 "record_uid", f"{first_name[:5]}.{last_name}.{fake.pyint(1000, 9999)}"
             ),
@@ -281,9 +299,13 @@ def kelvin_user_object(docker_hostname, kelvin_session, random_name, source_uid)
             workgroups=kwargs.get("workgroups", {}),
             school_classes=kwargs.get("school_classes", {})
             if roles == ("staff",)
-            else {school: sorted([random_name(4), random_name(4)]) for school in schools},
+            else {
+                school: sorted([random_name(4), random_name(4)]) for school in schools
+            },
             source_uid=kwargs.get("source_uid", source_uid),
             session=kwargs.get("session", kelvin_session(docker_hostname)),
+            legal_guardians=kwargs.get("legal_guardians", []),
+            legal_wards=kwargs.get("legal_wards", []),
         )
 
     return _func
@@ -311,7 +333,9 @@ async def make_sender_user(
         :param ous: The new users ous
         :return: The json used to create the user via the API
         """
-        user_obj: User = kelvin_user_object(roles, ous, session=kelvin_session(docker_hostname))
+        user_obj: User = kelvin_user_object(
+            roles, ous, session=kelvin_session(docker_hostname)
+        )
         password = user_obj.password
         await user_obj.save()
         user_obj.password = password
@@ -334,9 +358,13 @@ async def make_sender_user(
             # h11._util.LocalProtocolError: Too much data for declared Content-Length
             async with Session(**kelvin_session_kwargs(host)) as session:
                 try:
-                    user = await UserResource(session=session).get(name=user_dict["name"])
+                    user = await UserResource(session=session).get(
+                        name=user_dict["name"]
+                    )
                     await user.delete()
-                    print(f"Success deleting user {user_dict['name']!r} from host {host!r}.")
+                    print(
+                        f"Success deleting user {user_dict['name']!r} from host {host!r}."
+                    )
                 except NoObject:
                     print(f"No user {user_dict['name']!r} on {host!r}.")
 
@@ -362,11 +390,15 @@ def wait_for_kelvin_object_exists():
             func = getattr(resource, method)
             try:
                 res = await func(**method_kwargs)
-                print(f"OK: received answer for {resource_cls.__name__}.{method}({method_kwargs!r})")
+                print(
+                    f"OK: received answer for {resource_cls.__name__}.{method}({method_kwargs!r})"
+                )
                 return res
             except NoObject as exc:
                 error = exc
-                print(f"Waiting for {resource_cls.__name__}.{method}({method_kwargs!r}): {exc!s}")
+                print(
+                    f"Waiting for {resource_cls.__name__}.{method}({method_kwargs!r}): {exc!s}"
+                )
                 await session.close()
                 await asyncio.sleep(1)
                 session.open()
@@ -478,7 +510,10 @@ async def make_kelvin_workgroup_on_id_connector(kelvin_session, id_connector_hos
     created_workgroups: List[Tuple[str, str, str]] = []
 
     async def _func(
-        school_name: str, wokrgroup_name: str = None, description: str = None, users: List[str] = None
+        school_name: str,
+        wokrgroup_name: str = None,
+        description: str = None,
+        users: List[str] = None,
     ) -> WorkGroup:
         wg_obj = WorkGroup(
             name=wokrgroup_name or fake.user_name(),
@@ -495,7 +530,9 @@ async def make_kelvin_workgroup_on_id_connector(kelvin_session, id_connector_hos
 
     for host, name, school in created_workgroups:
         try:
-            _wg = await WorkGroupResource(session=kelvin_session(host)).get(name=name, school=school)
+            _wg = await WorkGroupResource(session=kelvin_session(host)).get(
+                name=name, school=school
+            )
             await _wg.delete()
             print(f"Success deleting work group {name!r} from host {host!r}.")
         except NoObject:
@@ -503,11 +540,16 @@ async def make_kelvin_workgroup_on_id_connector(kelvin_session, id_connector_hos
 
 
 @pytest_asyncio.fixture()
-async def make_kelvin_school_class_on_id_connector(kelvin_session, id_connector_host_name):
+async def make_kelvin_school_class_on_id_connector(
+    kelvin_session, id_connector_host_name
+):
     created_school_classes: List[Tuple[str, str, str]] = []
 
     async def _func(
-        school_name: str, school_class_name: str = None, description: str = None, users: List[str] = None
+        school_name: str,
+        school_class_name: str = None,
+        description: str = None,
+        users: List[str] = None,
     ) -> SchoolClass:
         sc_obj = SchoolClass(
             name=school_class_name or fake.user_name(),
@@ -517,14 +559,18 @@ async def make_kelvin_school_class_on_id_connector(kelvin_session, id_connector_
             users=users or [],
         )
         await sc_obj.save()
-        created_school_classes.append((id_connector_host_name, sc_obj.name, sc_obj.school))
+        created_school_classes.append(
+            (id_connector_host_name, sc_obj.name, sc_obj.school)
+        )
         return sc_obj
 
     yield _func
 
     for host, name, school in created_school_classes:
         try:
-            _sc = await SchoolClassResource(session=kelvin_session(host)).get(name=name, school=school)
+            _sc = await SchoolClassResource(session=kelvin_session(host)).get(
+                name=name, school=school
+            )
             await _sc.delete()
             print(f"Success deleting school class {name!r} from host {host!r}.")
         except NoObject:
@@ -538,6 +584,7 @@ async def make_sender_user_special(
     kelvin_session_kwargs,
     docker_hostname,
     id_broker_fqdn,
+    wait_for_kelvin_user_on_id_broker,
 ):
     """
     Fixture factory to create users on the apps host system. They are created
@@ -560,7 +607,11 @@ async def make_sender_user_special(
                 print(f"No user {username!r} on {host!r}.")
 
     async def _make_sender_user_special(
-        roles=("student",), ous=("DEMOSCHOOL",), s_a_name="Traeger1", **kwargs
+        roles=("student",),
+        ous=("DEMOSCHOOL",),
+        s_a_name="Traeger1",
+        create_related_users=False,
+        **kwargs,
     ):
         """
         Creates a user on the hosts UCS system via Kelvin-API-Client
@@ -568,6 +619,9 @@ async def make_sender_user_special(
 
         :param roles: The new users roles
         :param ous: The new users ous
+        :param create_related_users: If a related user should be created.
+            To test the `legal_guardians` and `legal_wards` attributes, we need to create an
+            additional user and add their name to the corresponding attribute of the primary object.
         :return: The json used to create the user via the API
         """
         nonlocal _s_a_name
@@ -575,6 +629,38 @@ async def make_sender_user_special(
         user_obj: User = kelvin_user_object(
             roles, ous, session=kelvin_session(docker_hostname), **kwargs
         )
+
+        if create_related_users:
+            if "legal_guardian" in roles:
+                # to add users to the legal_wards attribute, we need to create a student
+                student_user_obj: User = kelvin_user_object(
+                    ("student",), ous, session=kelvin_session(docker_hostname), **kwargs
+                )
+                await student_user_obj.save()
+                await wait_for_kelvin_user_on_id_broker(
+                    s_a_name=s_a_name,
+                    school=student_user_obj.school,
+                    name=student_user_obj.name,
+                )
+                created_users.append(student_user_obj.as_dict())
+                user_obj.legal_wards = [student_user_obj.name]
+            elif "student" in roles:
+                # to add users to the legal_guardians attribute, we need to create a student
+                legal_guardian_user_obj: User = kelvin_user_object(
+                    ("legal_guardian",),
+                    ous,
+                    session=kelvin_session(docker_hostname),
+                    **kwargs,
+                )
+                await legal_guardian_user_obj.save()
+                await wait_for_kelvin_user_on_id_broker(
+                    s_a_name=s_a_name,
+                    school=legal_guardian_user_obj.school,
+                    name=legal_guardian_user_obj.name,
+                )
+                created_users.append(legal_guardian_user_obj.as_dict())
+                user_obj.legal_guardians = [legal_guardian_user_obj.name]
+
         password = user_obj.password
         await user_obj.save()
         user_obj.password = password
