@@ -51,7 +51,9 @@ from idbroker.id_broker_client import (  # isort:skip  # noqa: E402
 )
 from conftest import get_class_id, get_workgroup_id  # isort:skip  # noqa: E402
 
-CONFIG_PATH = "/var/lib/univention-appcenter/apps/ucsschool-id-connector/conf/school_authorities"
+CONFIG_PATH = (
+    "/var/lib/univention-appcenter/apps/ucsschool-id-connector/conf/school_authorities"
+)
 SYNC_SCRIPT = "/var/lib/univention-appcenter/apps/ucsschool-id-connector/conf/plugins/packages/idbroker/initial_sync.py"  # noqa: E501
 ldap = LDAPAccess()
 
@@ -68,7 +70,9 @@ async def get_ou_id(
 ) -> str:
     ldap_filter = f"(&(objectClass=ucsschoolOrganizationalUnit)(ou={ou}))"
     objects = await ldap.search(
-        base=os.environ.get("ldap_base"), filter_s=ldap_filter, attributes=InitSync.GROUP_ATTRS
+        base=os.environ.get("ldap_base"),
+        filter_s=ldap_filter,
+        attributes=InitSync.GROUP_ATTRS,
     )
     return objects[0].entryUUID.value
 
@@ -77,7 +81,9 @@ async def to_id_broker_user_without_groups(
     user: Dict[str, Any],
 ) -> IDBrokerUserObject:
     objects = await ldap.search(
-        base=os.environ.get("ldap_base"), filter_s=f"(uid={user['name']})", attributes=["entryUUID"]
+        base=os.environ.get("ldap_base"),
+        filter_s=f"(uid={user['name']})",
+        attributes=["entryUUID"],
     )
     u_id = objects[0].entryUUID.value
     return IDBrokerUserObject(
@@ -85,7 +91,11 @@ async def to_id_broker_user_without_groups(
         user_name=user["name"],
         first_name=user["firstname"],
         last_name=user["lastname"],
-        context={user["school"]: SchoolContext(classes=[], workgroups=[], roles=user["roles"])},
+        context={
+            user["school"]: SchoolContext(
+                classes=[], workgroups=[], roles=user["roles"]
+            )
+        },
     )
 
 
@@ -106,7 +116,9 @@ def get_corresponding_broker_obj(sender_obj, id_broker_objects):
 def create_school_on_broker(kelvin_school_on_sender):
     async def _func(school_authority):
         ous = await InitSync.get_ous(ou=kelvin_school_on_sender.name)
-        obj = get_corresponding_broker_obj(sender_obj=kelvin_school_on_sender, id_broker_objects=ous)
+        obj = get_corresponding_broker_obj(
+            sender_obj=kelvin_school_on_sender, id_broker_objects=ous
+        )
         school_client = IDBrokerSchool(school_authority, "id_broker")
         await school_client.create(obj)
 
@@ -124,20 +136,26 @@ async def test_sync_object_workgroup(
     schedule_schools_delete,
     set_school_authority_on_id_connector,
 ):
-    school_authority = await set_school_authority_on_id_connector(schools=["name-is-not-used"])
+    school_authority = await set_school_authority_on_id_connector(
+        schools=["name-is-not-used"]
+    )
     await create_school_on_broker(school_authority)
     await schedule_schools_delete(
         school_authority=school_authority, schools=[kelvin_school_on_sender.name]
     )
     InitSync.WORKGROUP_CLIENT = IDBrokerWorkGroup(school_authority, "id_broker")
-    work_group = await make_kelvin_workgroup_on_id_connector(school_name=kelvin_school_on_sender.name)
+    work_group = await make_kelvin_workgroup_on_id_connector(
+        school_name=kelvin_school_on_sender.name
+    )
     await make_sender_user_special(
         ous=[kelvin_school_on_sender.name],
         workgroups={kelvin_school_on_sender.name: [work_group.name]},
     )
     work_groups = await InitSync.get_workgroups(ou=kelvin_school_on_sender.name)
     exists = not dry_run
-    obj = get_corresponding_broker_obj(sender_obj=work_group, id_broker_objects=work_groups)
+    obj = get_corresponding_broker_obj(
+        sender_obj=work_group, id_broker_objects=work_groups
+    )
     await InitSync.sync_object(obj=obj, sync_members=False, dry_run=dry_run)
     assert await InitSync.WORKGROUP_CLIENT.exists(obj.id) is exists
     if exists:
@@ -156,7 +174,9 @@ async def test_sync_object_school_class(
     schedule_schools_delete,
     set_school_authority_on_id_connector,
 ):
-    school_authority = await set_school_authority_on_id_connector(schools=["name-is-not-used"])
+    school_authority = await set_school_authority_on_id_connector(
+        schools=["name-is-not-used"]
+    )
     await schedule_schools_delete(
         school_authority=school_authority, schools=[kelvin_school_on_sender.name]
     )
@@ -170,7 +190,9 @@ async def test_sync_object_school_class(
     )
     school_classes = await InitSync.get_classes(ou=kelvin_school_on_sender.name)
     exists = not dry_run
-    obj = get_corresponding_broker_obj(sender_obj=school_class, id_broker_objects=school_classes)
+    obj = get_corresponding_broker_obj(
+        sender_obj=school_class, id_broker_objects=school_classes
+    )
     await InitSync.sync_object(obj=obj, sync_members=False, dry_run=dry_run)
     assert await InitSync.SCHOOL_CLASS_CLIENT.exists(obj.id) is exists
     if exists:
@@ -187,7 +209,9 @@ async def test_sync_object_workgroup_sync_members(
     schedule_schools_delete,
     set_school_authority_on_id_connector,
 ):
-    school_authority = await set_school_authority_on_id_connector(schools=["name-is-not-used"])
+    school_authority = await set_school_authority_on_id_connector(
+        schools=["name-is-not-used"]
+    )
     await schedule_schools_delete(
         school_authority=school_authority, schools=[kelvin_school_on_sender.name]
     )
@@ -204,7 +228,9 @@ async def test_sync_object_workgroup_sync_members(
         school_name=kelvin_school_on_sender.name, users=[user["name"]]
     )
     work_groups = await InitSync.get_workgroups(ou=kelvin_school_on_sender.name)
-    obj = get_corresponding_broker_obj(sender_obj=work_group, id_broker_objects=work_groups)
+    obj = get_corresponding_broker_obj(
+        sender_obj=work_group, id_broker_objects=work_groups
+    )
     assert await InitSync.WORKGROUP_CLIENT.exists(obj.id) is False
     # This is the line we want to test:
     await InitSync.sync_object(obj=obj, sync_members=True, dry_run=False)
@@ -242,7 +268,9 @@ async def test_sync_object_school_class_sync_members(
         school_name=kelvin_school_on_sender.name, users=[user["name"]]
     )
     school_classes = await InitSync.get_classes(ou=kelvin_school_on_sender.name)
-    obj = get_corresponding_broker_obj(sender_obj=school_class, id_broker_objects=school_classes)
+    obj = get_corresponding_broker_obj(
+        sender_obj=school_class, id_broker_objects=school_classes
+    )
     assert await InitSync.SCHOOL_CLASS_CLIENT.exists(obj.id) is False
     # This is the line we want to test:
     await InitSync.sync_object(obj=obj, sync_members=True, dry_run=False)
@@ -254,7 +282,10 @@ async def test_sync_object_school_class_sync_members(
 @pytest.mark.asyncio
 @pytest.mark.parametrize("dry_run", [True, False], ids=lambda x: f"dry_run={x}")
 async def test_sync_object_school_single(
-    kelvin_schools_on_sender, dry_run, schedule_schools_delete, set_school_authority_on_id_connector
+    kelvin_schools_on_sender,
+    dry_run,
+    schedule_schools_delete,
+    set_school_authority_on_id_connector,
 ):
     school_authority = await set_school_authority_on_id_connector(
         schools=["name-is-not-used"], active=False
@@ -263,7 +294,9 @@ async def test_sync_object_school_single(
     await asyncio.sleep(3)
     school = await kelvin_schools_on_sender(1)
     school_name = school[0].name
-    await schedule_schools_delete(school_authority=school_authority, schools=[school_name])
+    await schedule_schools_delete(
+        school_authority=school_authority, schools=[school_name]
+    )
     ous = await InitSync.get_ous(ou=school_name)
     exists = not dry_run
     obj = get_corresponding_broker_obj(sender_obj=school[0], id_broker_objects=ous)
@@ -293,7 +326,9 @@ async def test_script_dry_run(
     classes_client = IDBrokerSchoolClass(school_authority, "id_broker")
     workgroups_client = IDBrokerWorkGroup(school_authority, "id_broker")
     await asyncio.sleep(3)
-    work_group = await make_kelvin_workgroup_on_id_connector(school_name=kelvin_school_on_sender.name)
+    work_group = await make_kelvin_workgroup_on_id_connector(
+        school_name=kelvin_school_on_sender.name
+    )
     user = await make_sender_user_special(
         ous=[kelvin_school_on_sender.name],
         workgroups={kelvin_school_on_sender.name: [work_group.name]},
@@ -301,8 +336,12 @@ async def test_script_dry_run(
     school_class = await make_kelvin_school_class_on_id_connector(
         school_name=kelvin_school_on_sender.name, users=[user["name"]]
     )
-    school_class_id = await get_class_id(ou=kelvin_school_on_sender.name, name=school_class.name)
-    work_group_id = await get_workgroup_id(ou=kelvin_school_on_sender.name, name=work_group.name)
+    school_class_id = await get_class_id(
+        ou=kelvin_school_on_sender.name, name=school_class.name
+    )
+    work_group_id = await get_workgroup_id(
+        ou=kelvin_school_on_sender.name, name=work_group.name
+    )
     ou_id = await get_ou_id(ou=kelvin_school_on_sender.name)
     assert await classes_client.exists(school_class_id) is False
     assert await workgroups_client.exists(work_group_id) is False
@@ -339,7 +378,9 @@ async def test_script_single_ou(
     classes_client = IDBrokerSchoolClass(school_authority, "id_broker")
     workgroups_client = IDBrokerWorkGroup(school_authority, "id_broker")
     await asyncio.sleep(3)
-    work_group = await make_kelvin_workgroup_on_id_connector(school_name=kelvin_school_on_sender.name)
+    work_group = await make_kelvin_workgroup_on_id_connector(
+        school_name=kelvin_school_on_sender.name
+    )
     user = await make_sender_user_special(
         ous=[kelvin_school_on_sender.name],
         workgroups={kelvin_school_on_sender.name: [work_group.name]},
@@ -349,7 +390,9 @@ async def test_script_single_ou(
     )
     other_school = await kelvin_schools_on_sender(1)
     other_school_name = other_school[0].name
-    other_school_class = await make_kelvin_school_class_on_id_connector(school_name=other_school_name)
+    other_school_class = await make_kelvin_school_class_on_id_connector(
+        school_name=other_school_name
+    )
     await make_sender_user_special(
         ous=[other_school_name],
         school_classes={other_school_name: [other_school_class.name]},
@@ -357,8 +400,12 @@ async def test_script_single_ou(
     run_initial_sync_script(
         call_arguments=["--school", kelvin_school_on_sender.name],
     )
-    work_group_id = await get_workgroup_id(ou=kelvin_school_on_sender.name, name=work_group.name)
-    school_class_id = await get_class_id(ou=kelvin_school_on_sender.name, name=school_class.name)
+    work_group_id = await get_workgroup_id(
+        ou=kelvin_school_on_sender.name, name=work_group.name
+    )
+    school_class_id = await get_class_id(
+        ou=kelvin_school_on_sender.name, name=school_class.name
+    )
     ou_id = await get_ou_id(ou=kelvin_school_on_sender.name)
     assert await school_client.exists(ou_id) is True
     assert await workgroups_client.exists(work_group_id) is True
@@ -368,7 +415,9 @@ async def test_script_single_ou(
     group = await classes_client.get(school_class_id)
     assert group.members == []
     # other schools should not be synced.
-    school_class_id = await get_class_id(ou=other_school_name, name=other_school_class.name)
+    school_class_id = await get_class_id(
+        ou=other_school_name, name=other_school_class.name
+    )
     ou_id = await get_ou_id(ou=other_school_name)
     assert await school_client.exists(ou_id) is False
     assert await classes_client.exists(school_class_id) is False
@@ -414,9 +463,13 @@ async def test_script_single_ou_sync_members(
         school_name=kelvin_school_on_sender.name, users=[user["name"]]
     )
     work_groups = await InitSync.get_workgroups(ou=kelvin_school_on_sender.name)
-    wg_obj = get_corresponding_broker_obj(sender_obj=work_group, id_broker_objects=work_groups)
+    wg_obj = get_corresponding_broker_obj(
+        sender_obj=work_group, id_broker_objects=work_groups
+    )
     school_classes = await InitSync.get_classes(ou=kelvin_school_on_sender.name)
-    sc_obj = get_corresponding_broker_obj(sender_obj=school_class, id_broker_objects=school_classes)
+    sc_obj = get_corresponding_broker_obj(
+        sender_obj=school_class, id_broker_objects=school_classes
+    )
     assert await InitSync.WORKGROUP_CLIENT.exists(wg_obj.id) is False
     assert await InitSync.SCHOOL_CLASS_CLIENT.exists(sc_obj.id) is False
     # This is the line we want to test:
@@ -452,9 +505,15 @@ async def test_script_only_sync_groups_with_members(
     school_class = await make_kelvin_school_class_on_id_connector(
         school_name=kelvin_school_on_sender.name
     )
-    work_group = await make_kelvin_workgroup_on_id_connector(school_name=kelvin_school_on_sender.name)
-    work_group_id = await get_workgroup_id(ou=f"{kelvin_school_on_sender.name}", name=work_group.name)
-    school_class_id = await get_class_id(ou=f"{kelvin_school_on_sender.name}", name=school_class.name)
+    work_group = await make_kelvin_workgroup_on_id_connector(
+        school_name=kelvin_school_on_sender.name
+    )
+    work_group_id = await get_workgroup_id(
+        ou=f"{kelvin_school_on_sender.name}", name=work_group.name
+    )
+    school_class_id = await get_class_id(
+        ou=f"{kelvin_school_on_sender.name}", name=school_class.name
+    )
     run_initial_sync_script(
         call_arguments=["--school", kelvin_school_on_sender.name],
     )
@@ -483,7 +542,9 @@ async def test_script_multi_schools(
     workgroups_client = IDBrokerWorkGroup(school_authority, "id_broker")
     await asyncio.sleep(3)
     sender_school_1, sender_school2 = await kelvin_schools_on_sender(2)
-    work_group = await make_kelvin_workgroup_on_id_connector(school_name=sender_school_1.name)
+    work_group = await make_kelvin_workgroup_on_id_connector(
+        school_name=sender_school_1.name
+    )
     user = await make_sender_user_special(
         ous=[sender_school_1.name],
         workgroups={sender_school_1.name: [work_group.name]},
@@ -492,7 +553,9 @@ async def test_script_multi_schools(
         school_name=sender_school_1.name, users=[user["name"]]
     )
     other_school_name = sender_school2.name
-    other_work_group = await make_kelvin_workgroup_on_id_connector(school_name=other_school_name)
+    other_work_group = await make_kelvin_workgroup_on_id_connector(
+        school_name=other_school_name
+    )
     other_user = await make_sender_user_special(
         ous=[other_school_name],
         workgroups={other_school_name: [other_work_group.name]},
@@ -505,20 +568,28 @@ async def test_script_multi_schools(
         ou_id = await get_ou_id(ou=ou)
         assert await school_client.exists(ou_id) is True
     # School classes should be created and have no members.
-    school_class_id = await get_class_id(ou=sender_school_1.name, name=school_class.name)
+    school_class_id = await get_class_id(
+        ou=sender_school_1.name, name=school_class.name
+    )
     assert await classes_client.exists(school_class_id) is True
     group = await classes_client.get(school_class_id)
     assert group.members == []
-    school_class_id = await get_class_id(ou=sender_school2.name, name=other_school_class.name)
+    school_class_id = await get_class_id(
+        ou=sender_school2.name, name=other_school_class.name
+    )
     assert await classes_client.exists(school_class_id) is True
     group = await classes_client.get(school_class_id)
     assert group.members == []
     # Workgroups should be created and have no members.
-    work_group_id = await get_workgroup_id(ou=sender_school_1.name, name=work_group.name)
+    work_group_id = await get_workgroup_id(
+        ou=sender_school_1.name, name=work_group.name
+    )
     assert await workgroups_client.exists(work_group_id) is True
     group = await workgroups_client.get(work_group_id)
     assert group.members == []
-    work_group_id = await get_workgroup_id(ou=sender_school2.name, name=other_work_group.name)
+    work_group_id = await get_workgroup_id(
+        ou=sender_school2.name, name=other_work_group.name
+    )
     assert await workgroups_client.exists(work_group_id) is True
     group = await workgroups_client.get(work_group_id)
     assert group.members == []
