@@ -14,12 +14,19 @@ import requests.packages.urllib3
 from diskcache import Index
 from gevent.lock import BoundedSemaphore
 from locust import HttpUser
-from locust.clients import HttpSession as LocustClient, ResponseContextManager as LucustCMResponse
+from locust.clients import (
+    HttpSession as LocustClient,
+    ResponseContextManager as LucustCMResponse,
+)
 from pydantic import BaseModel
 from urllib3.exceptions import InsecureRequestWarning
 
-PROVISIONING_SCHOOL_URL = "/ucsschool/apis/provisioning/v1/{school_authority}/schools/{id}"
-PROVISIONING_CLASS_URL = "/ucsschool/apis/provisioning/v1/{school_authority}/classes/{id}"
+PROVISIONING_SCHOOL_URL = (
+    "/ucsschool/apis/provisioning/v1/{school_authority}/schools/{id}"
+)
+PROVISIONING_CLASS_URL = (
+    "/ucsschool/apis/provisioning/v1/{school_authority}/classes/{id}"
+)
 PROVISIONING_USER_URL = "/ucsschool/apis/provisioning/v1/{school_authority}/users/{id}"
 UCSSCHOOL_APIS_TOKEN_URL = "/ucsschool/apis/auth/token"
 BASE_DIR = Path("/var/lib/id-broker-performance-tests")
@@ -28,8 +35,12 @@ USED_SCHOOLS_LOG = BASE_DIR / "used_schools.txt"
 ENV_DATA_DIR = "ID_BROKER_TEST_DATA"
 
 try:
-    PROVISIONING_USER_TRAEGER1_SECRET = os.environ["UCS_ENV_PROVISIONING_USER_TRAEGER1_SECRET"]
-    PROVISIONING_USER_TRAEGER2_SECRET = os.environ["UCS_ENV_PROVISIONING_USER_TRAEGER2_SECRET"]
+    PROVISIONING_USER_TRAEGER1_SECRET = os.environ[
+        "UCS_ENV_PROVISIONING_USER_TRAEGER1_SECRET"
+    ]
+    PROVISIONING_USER_TRAEGER2_SECRET = os.environ[
+        "UCS_ENV_PROVISIONING_USER_TRAEGER2_SECRET"
+    ]
 except KeyError as err:
     raise ValueError(f"Missing environment variable {err}!")
 
@@ -121,7 +132,11 @@ class TestData:
         group_data = school_data.pop("groups")
         groups = {}
         for group_name, group_attrs in group_data.items():
-            pseudonyms = {k: v for k, v in group_attrs.items() if k.startswith("idBrokerPseudonym")}
+            pseudonyms = {
+                k: v
+                for k, v in group_attrs.items()
+                if k.startswith("idBrokerPseudonym")
+            }
             groups[group_name] = GroupData(
                 id=group_attrs["id"],
                 name=group_name,
@@ -131,7 +146,9 @@ class TestData:
         user_data = school_data.pop("users")
         users = {}
         for user_name, user_attrs in user_data.items():
-            pseudonyms = {k: v for k, v in user_attrs.items() if k.startswith("idBrokerPseudonym")}
+            pseudonyms = {
+                k: v for k, v in user_attrs.items() if k.startswith("idBrokerPseudonym")
+            }
             users[user_name] = UserData(
                 id=user_attrs["id"],
                 name=user_name,
@@ -139,9 +156,15 @@ class TestData:
                 pseudonyms=pseudonyms,
                 ucsschoolRole=user_attrs["ucsschoolRole"],
             )
-        pseudonyms = {k: v for k, v in school_data.items() if k.startswith("idBrokerPseudonym")}
+        pseudonyms = {
+            k: v for k, v in school_data.items() if k.startswith("idBrokerPseudonym")
+        }
         return SchoolData(
-            name=school_name, pseudonyms=pseudonyms, groups=groups, users=users, **school_data
+            name=school_name,
+            pseudonyms=pseudonyms,
+            groups=groups,
+            users=users,
+            **school_data,
         )
 
     @staticmethod
@@ -234,7 +257,9 @@ def json_to_dict_cache(source_path: Path, target_path: Path) -> None:
             if object_type == "groups":
                 for classes_dict in data[school_authority].values():
                     for long_name, class_data in classes_dict.items():
-                        class_name = long_name[len(f"{school_authority}-{school_name}-") :]
+                        class_name = long_name[
+                            len(f"{school_authority}-{school_name}-") :
+                        ]
                         school["groups"][class_name] = class_data
                         school["groups"][class_name]["memberUid"] = [
                             uid[len(f"{school_authority}-{school_name}-") :]
@@ -250,7 +275,9 @@ def json_to_dict_cache(source_path: Path, target_path: Path) -> None:
                         traeger["prov_api_admins"][key] = data[school_authority][key]
                     else:
                         for long_name, user_data in data[school_authority][key].items():
-                            user_name = long_name[len(f"{school_authority}-{school_name}-") :]
+                            user_name = long_name[
+                                len(f"{school_authority}-{school_name}-") :
+                            ]
                             school["users"][user_name] = user_data
             else:
                 raise RuntimeError(f"Unknown object_type={object_type!r}.")
@@ -295,11 +322,14 @@ def get_classes(
     for school_authority in school_authorities:
         res[school_authority] = {}
         school_authority_data = data.school_authority(school_authority)
-        schools = random.choices(list(school_authority_data.schools.keys()), k=schools_per_authority)
+        schools = random.choices(
+            list(school_authority_data.schools.keys()), k=schools_per_authority
+        )
         for school in schools:
             school_data = data.school(school_authority, school)
             res[school_authority][school] = {
-                group_data.name: group_data.id for group_data in school_data.groups.values()
+                group_data.name: group_data.id
+                for group_data in school_data.groups.values()
             }
     return res
 
@@ -321,14 +351,19 @@ def get_users(
     for school_authority in school_authorities:
         res[school_authority] = {}
         school_authority_data = data.school_authority(school_authority)
-        schools = random.choices(list(school_authority_data.schools.keys()), k=schools_per_authority)
+        schools = random.choices(
+            list(school_authority_data.schools.keys()), k=schools_per_authority
+        )
         for school in schools:
             previously_used_ous_for_authority = [
                 used for used in previously_used_ous if used[0] == school_authority
             ]
             while (school_authority, school) in previously_used_ous:
                 school = random.choice(list(school_authority_data.schools.keys()))
-                if len(previously_used_ous_for_authority) >= school_authority_data.number_of_schools:
+                if (
+                    len(previously_used_ous_for_authority)
+                    >= school_authority_data.number_of_schools
+                ):
                     break
             school_data = data.school(school_authority, school)
             res[school_authority][school] = {
@@ -352,7 +387,9 @@ def get_users_with_passwords(
     for school_authority in data.school_authorities:
         res[school_authority] = {}
         school_authority_data = data.school_authority(school_authority)
-        schools = random.choices(list(school_authority_data.schools.keys()), k=schools_per_authority)
+        schools = random.choices(
+            list(school_authority_data.schools.keys()), k=schools_per_authority
+        )
         for school in schools:
             school_data = data.school(school_authority, school)
             for user_data in school_data.users.values():
@@ -378,7 +415,9 @@ def get_schools(data: TestData) -> Dict[str, Dict[str, str]]:
         res[school_authority] = school_authority_data.schools
         for ou in used_ous:
             if ou in res[school_authority]:
-                del res[school_authority][ou]  # remove OUs whose objects were altered in previous tests
+                del res[school_authority][
+                    ou
+                ]  # remove OUs whose objects were altered in previous tests
     return res
 
 
@@ -400,16 +439,21 @@ def get_member_data(
                 school_data = data.school(school_authority, school)
             except IndexError:
                 logging.warning(
-                    "*** Ignoring unknown school %r in authority %r.", school, school_authority
+                    "*** Ignoring unknown school %r in authority %r.",
+                    school,
+                    school_authority,
                 )
                 continue
             res[school_authority][school] = {
-                group_name: group_data.memberUid for group_name, group_data in school_data.groups.items()
+                group_name: group_data.memberUid
+                for group_name, group_data in school_data.groups.items()
             }
     return res
 
 
-def get_role_data(data: TestData, schools: Iterable[str]) -> Dict[str, Dict[str, Dict[str, List[str]]]]:
+def get_role_data(
+    data: TestData, schools: Iterable[str]
+) -> Dict[str, Dict[str, Dict[str, List[str]]]]:
     """
     Get school classes and members.
 
@@ -425,21 +469,22 @@ def get_role_data(data: TestData, schools: Iterable[str]) -> Dict[str, Dict[str,
                 school_data = data.school(school_authority, school)
             except IndexError:
                 logging.warning(
-                    "*** Ignoring unknown school %r in authority %r.", school, school_authority
+                    "*** Ignoring unknown school %r in authority %r.",
+                    school,
+                    school_authority,
                 )
                 continue
             res[school_authority][school] = {
-                username: user_data.ucsschoolRole for username, user_data in school_data.users.items()
+                username: user_data.ucsschoolRole
+                for username, user_data in school_data.users.items()
             }
     return res
 
 
-class ResponseError(Exception):
-    ...
+class ResponseError(Exception): ...
 
 
-class TokenError(Exception):
-    ...
+class TokenError(Exception): ...
 
 
 class ProvisioningSchool(BaseModel):
@@ -492,7 +537,9 @@ class FastAPIClient(HttpUser):
         super().__init__(*args, **kwargs)
         self.auth_username = ""
         self.auth_password = ""
-        self._access_token = ""  # do not access this var directly, use the "self.access_token" property
+        self._access_token = (
+            ""  # do not access this var directly, use the "self.access_token" property
+        )
         self._update_time = 0.0
         self._sem_token = BoundedSemaphore()  # guard access to self._access_token
 
@@ -514,7 +561,9 @@ class FastAPIClient(HttpUser):
             {"accept": "application/json", "Authorization": self.access_token}
         )
         logging.debug("_head() args=%r kwargs=%r", args, kwargs)
-        with self.client.head(*args, catch_response=True, verify=False, **kwargs) as response:
+        with self.client.head(
+            *args, catch_response=True, verify=False, **kwargs
+        ) as response:
             return cast(LucustCMResponse, response)
 
     def _get_json(
@@ -524,12 +573,16 @@ class FastAPIClient(HttpUser):
             {"accept": "application/json", "Authorization": self.access_token}
         )
         logging.debug("_get_json() args=%r kwargs=%r", args, kwargs)
-        with self.client.get(*args, catch_response=True, verify=False, **kwargs) as response:
+        with self.client.get(
+            *args, catch_response=True, verify=False, **kwargs
+        ) as response:
             response = cast(LucustCMResponse, response)
             response_json = self._response_to_json(response)
             return response_json, response
 
-    def _get_json_list(self, *args, **kwargs) -> Tuple[List[Dict[str, Any]], LucustCMResponse]:
+    def _get_json_list(
+        self, *args, **kwargs
+    ) -> Tuple[List[Dict[str, Any]], LucustCMResponse]:
         res, response = self._get_json(*args, **kwargs)
         if not res:
             res = []
@@ -540,7 +593,9 @@ class FastAPIClient(HttpUser):
             {"accept": "application/json", "Authorization": self.access_token}
         )
         logging.debug("_post_json() args=%r kwargs=%r", args, kwargs)
-        with self.client.post(*args, catch_response=True, verify=False, **kwargs) as response:
+        with self.client.post(
+            *args, catch_response=True, verify=False, **kwargs
+        ) as response:
             response = cast(LucustCMResponse, response)
             response_json = self._response_to_json(response)
             return response_json, response
@@ -550,7 +605,9 @@ class FastAPIClient(HttpUser):
             {"accept": "application/json", "Authorization": self.access_token}
         )
         logging.debug("_put_json() args=%r kwargs=%r", args, kwargs)
-        with self.client.put(*args, catch_response=True, verify=False, **kwargs) as response:
+        with self.client.put(
+            *args, catch_response=True, verify=False, **kwargs
+        ) as response:
             response = cast(LucustCMResponse, response)
             response_json = self._response_to_json(response)
             return response_json, response
@@ -560,7 +617,9 @@ class FastAPIClient(HttpUser):
             {"accept": "application/json", "Authorization": self.access_token}
         )
         logging.debug("_delete() args=%r kwargs=%r", args, kwargs)
-        with self.client.delete(*args, catch_response=True, verify=False, **kwargs) as response:
+        with self.client.delete(
+            *args, catch_response=True, verify=False, **kwargs
+        ) as response:
             response = cast(LucustCMResponse, response)
             if response.status_code != 204:
                 msg = f"status code: {response.status_code} Response text: {response.text}"
@@ -591,7 +650,9 @@ class FastAPIClient(HttpUser):
     def _get_token_expiry(token: str) -> datetime.datetime:
         """Get the time at which `token` expires."""
         actual_token = token.rsplit(" ", 1)[-1]
-        payload = jwt.decode(actual_token, algorithm="HS256", options={"verify_signature": False})
+        payload = jwt.decode(
+            actual_token, algorithm="HS256", options={"verify_signature": False}
+        )
         exp: str = payload.get("exp")
         ts = int(exp)
         return datetime.datetime.fromtimestamp(ts)
@@ -599,12 +660,16 @@ class FastAPIClient(HttpUser):
     def _get_access_token(self, http_client, server) -> str:
         with self._sem_token:
             if not self._access_token or time.time() >= self._update_time:
-                logging.info(f"Fetching access token for {self.auth_username!r} from {server!r}...")
+                logging.info(
+                    f"Fetching access token for {self.auth_username!r} from {server!r}..."
+                )
                 url = f"https://{server}{self.auth_token_url}"
                 self._access_token = self._get_fastapi_token(
                     http_client, url, self.auth_username, self.auth_password
                 )
-                self._update_time = time.time() + 3600 - 10  # refresh (shortly before) every hour
+                self._update_time = (
+                    time.time() + 3600 - 10
+                )  # refresh (shortly before) every hour
         return self._access_token
 
     def _set_access_token(self, token: str) -> None:
@@ -612,11 +677,18 @@ class FastAPIClient(HttpUser):
             self._access_token = token
 
     @staticmethod
-    def _get_fastapi_token(client: LocustClient, url: str, username: str, password: str) -> str:
+    def _get_fastapi_token(
+        client: LocustClient, url: str, username: str, password: str
+    ) -> str:
         """Get an access token from the server."""
-        headers = {"accept": "application/json", "Content-Type": "application/x-www-form-urlencoded"}
+        headers = {
+            "accept": "application/json",
+            "Content-Type": "application/x-www-form-urlencoded",
+        }
         data = {"username": username, "password": password}
-        with client.post(url, data=data, headers=headers, catch_response=True, verify=False) as response:
+        with client.post(
+            url, data=data, headers=headers, catch_response=True, verify=False
+        ) as response:
             response = cast(LucustCMResponse, response)
             try:
                 response_json = response.json()
@@ -645,14 +717,18 @@ class FastAPIClient(HttpUser):
         res, _ = self._get_json_list(url, name=_url_name, params=params)
         return res
 
-    def _create_resource(self, url: str, _url_name: str = None, **body) -> Dict[str, Any]:
+    def _create_resource(
+        self, url: str, _url_name: str = None, **body
+    ) -> Dict[str, Any]:
         res, _ = self._post_json(url, name=_url_name, json=body)
         return res
 
     def _delete_resource(self, url: str, _url_name: str = None) -> LucustCMResponse:
         return self._delete(url, name=_url_name)
 
-    def _update_resource(self, url: str, _url_name: str = None, **body) -> Dict[str, Any]:
+    def _update_resource(
+        self, url: str, _url_name: str = None, **body
+    ) -> Dict[str, Any]:
         res, _ = self._put_json(url, name=_url_name, json=body)
         return res
 
@@ -674,7 +750,9 @@ class ProvisioningClient(FastAPIClient):
     def school_create(
         self, school_authority: str, obj_id: str, name: str, display_name: str = ""
     ) -> ProvisioningSchool:
-        url_path = PROVISIONING_SCHOOL_URL.format(school_authority=school_authority, id="").rstrip("/")
+        url_path = PROVISIONING_SCHOOL_URL.format(
+            school_authority=school_authority, id=""
+        ).rstrip("/")
         url = f"https://{self.host}{url_path}"
         data = {
             "id": obj_id,
@@ -684,14 +762,20 @@ class ProvisioningClient(FastAPIClient):
         res = self._create_resource(url, _url_name=PROVISIONING_SCHOOL_URL, **data)
         return ProvisioningSchool(school_authority=school_authority, **res)
 
-    def school_class_get(self, school_authority: str, obj_id: str) -> ProvisioningSchoolClass:
-        url_path = PROVISIONING_CLASS_URL.format(school_authority=school_authority, id=obj_id)
+    def school_class_get(
+        self, school_authority: str, obj_id: str
+    ) -> ProvisioningSchoolClass:
+        url_path = PROVISIONING_CLASS_URL.format(
+            school_authority=school_authority, id=obj_id
+        )
         url = f"https://{self.host}{url_path}"
         res = self._get_resource(url, _url_name=PROVISIONING_CLASS_URL)
         return ProvisioningSchoolClass(school_authority=school_authority, **res)
 
     def school_class_exists(self, school_authority: str, obj_id: str) -> bool:
-        url_path = PROVISIONING_CLASS_URL.format(school_authority=school_authority, id=obj_id)
+        url_path = PROVISIONING_CLASS_URL.format(
+            school_authority=school_authority, id=obj_id
+        )
         url = f"https://{self.host}{url_path}"
         res = self._head_resource(url, _url_name=PROVISIONING_CLASS_URL)
         return res.status_code == 200
@@ -705,7 +789,9 @@ class ProvisioningClient(FastAPIClient):
         description: str = "",
         members: List[str] = None,
     ) -> ProvisioningSchoolClass:
-        url_path = PROVISIONING_CLASS_URL.format(school_authority=school_authority, id="").rstrip("/")
+        url_path = PROVISIONING_CLASS_URL.format(
+            school_authority=school_authority, id=""
+        ).rstrip("/")
         url = f"https://{self.host}{url_path}"
         data = {
             "id": obj_id,
@@ -726,7 +812,9 @@ class ProvisioningClient(FastAPIClient):
         description: str = "",
         members: List[str] = None,
     ) -> ProvisioningSchoolClass:
-        url_path = PROVISIONING_CLASS_URL.format(school_authority=school_authority, id=obj_id)
+        url_path = PROVISIONING_CLASS_URL.format(
+            school_authority=school_authority, id=obj_id
+        )
         url = f"https://{self.host}{url_path}"
         data = {
             "id": obj_id,
@@ -739,18 +827,24 @@ class ProvisioningClient(FastAPIClient):
         return ProvisioningSchoolClass(school_authority=school_authority, **res)
 
     def school_class_remove(self, school_authority: str, obj_id: str) -> None:
-        url_path = PROVISIONING_CLASS_URL.format(school_authority=school_authority, id=obj_id)
+        url_path = PROVISIONING_CLASS_URL.format(
+            school_authority=school_authority, id=obj_id
+        )
         url = f"https://{self.host}{url_path}"
         self._delete_resource(url, _url_name=PROVISIONING_CLASS_URL)
 
     def user_get(self, school_authority: str, obj_id: str) -> ProvisioningUser:
-        url_path = PROVISIONING_USER_URL.format(school_authority=school_authority, id=obj_id)
+        url_path = PROVISIONING_USER_URL.format(
+            school_authority=school_authority, id=obj_id
+        )
         url = f"https://{self.host}{url_path}"
         res = self._get_resource(url, _url_name=PROVISIONING_USER_URL)
         return ProvisioningUser(school_authority=school_authority, **res)
 
     def user_exists(self, school_authority: str, obj_id: str) -> bool:
-        url_path = PROVISIONING_USER_URL.format(school_authority=school_authority, id=obj_id)
+        url_path = PROVISIONING_USER_URL.format(
+            school_authority=school_authority, id=obj_id
+        )
         url = f"https://{self.host}{url_path}"
         res = self._head_resource(url, _url_name=PROVISIONING_USER_URL)
         return res.status_code == 200
@@ -764,7 +858,9 @@ class ProvisioningClient(FastAPIClient):
         user_name: str,
         context: Dict[str, ProvisioningSchoolContext],
     ) -> ProvisioningUser:
-        url_path = PROVISIONING_USER_URL.format(school_authority=school_authority, id="").rstrip("/")
+        url_path = PROVISIONING_USER_URL.format(
+            school_authority=school_authority, id=""
+        ).rstrip("/")
         url = f"https://{self.host}{url_path}"
         data = {
             "id": obj_id,
@@ -785,7 +881,9 @@ class ProvisioningClient(FastAPIClient):
         user_name: str,
         context: Dict[str, ProvisioningSchoolContext],
     ) -> ProvisioningUser:
-        url_path = PROVISIONING_USER_URL.format(school_authority=school_authority, id=obj_id)
+        url_path = PROVISIONING_USER_URL.format(
+            school_authority=school_authority, id=obj_id
+        )
         url = f"https://{self.host}{url_path}"
         data = {
             "id": obj_id,
@@ -798,7 +896,9 @@ class ProvisioningClient(FastAPIClient):
         return ProvisioningUser(school_authority=school_authority, **res)
 
     def user_remove(self, school_authority: str, obj_id: str) -> None:
-        url_path = PROVISIONING_USER_URL.format(school_authority=school_authority, id=obj_id)
+        url_path = PROVISIONING_USER_URL.format(
+            school_authority=school_authority, id=obj_id
+        )
         url = f"https://{self.host}{url_path}"
         self._delete_resource(url, _url_name=PROVISIONING_USER_URL)
 
