@@ -3,7 +3,11 @@ from typing import List, Tuple
 
 from locust import events, task
 
-from performance_tests.common import ProvisioningClient, TestData, get_provisioning_api_admins
+from performance_tests.common import (
+    ProvisioningClient,
+    TestData,
+    get_provisioning_api_admins,
+)
 
 user_credentials: List[Tuple[str, str]] = []  # [(username, password), ..]
 
