@@ -19,7 +19,9 @@ from performance_tests.common import (
 school_authorities: List[str] = []  # ["Traeger1", "Traeger"]
 user_credentials: Dict[str, Tuple[str, str]] = {}  # [(username, password), ..]
 id_broker_schools: Dict[str, Dict[str, str]] = {}  # {sch_auth: {ou: uuid, ...}}
-id_broker_school_classes: Dict[str, Dict[str, Dict[str, str]]] = {}  # {sch_auth: {ou: {cl: uuid, ...}}}
+id_broker_school_classes: Dict[
+    str, Dict[str, Dict[str, str]]
+] = {}  # {sch_auth: {ou: {cl: uuid, ...}}}
 NUM_SCHOOLS_PER_SCHOOL_AUTHORITY = 5  # loading all OUs from test DB takes to long
 fake = Faker()
 used_schools = UsedSchools()
@@ -61,7 +63,9 @@ class ProvisioningAPIClient(ProvisioningClient):
                 first_name=fake.first_name(),
                 last_name=fake.last_name(),
                 user_name=username,
-                context={school: ProvisioningSchoolContext(classes=classes, roles=roles)},
+                context={
+                    school: ProvisioningSchoolContext(classes=classes, roles=roles)
+                },
             )
         except ResponseError as exc:
             logging.error(
@@ -76,5 +80,7 @@ class ProvisioningAPIClient(ProvisioningClient):
 
 @events.test_stop.add_listener
 def _(environment, **_kwargs):
-    logging.info("Used schools: %r", sorted(f"{s_a}-{ou}" for s_a, ou in used_schools.schools))
+    logging.info(
+        "Used schools: %r", sorted(f"{s_a}-{ou}" for s_a, ou in used_schools.schools)
+    )
     used_schools.persist()
