@@ -87,6 +87,8 @@ class SddbInternalUser(TypedDict):
     name: str  # UID
     school: str  # OU
     schools: List[str]  # OU1, OU2, ...
+    legal_guardians: List[str]  # UIDs of legal-guardians of a student
+    legal_wards: List[str]  # UIDs of legal-wards of a legal-guardian
     school_authority: str
     modifyTimestamp: str  # "2023-04-28T14:26:40"
     p0001: str  # idBrokerPseudonym0001
