@@ -15,7 +15,9 @@ def _env_is_not_empty():
     num_provisioned = 0
     for entity in ["users/user", "groups/group", "container/ou"]:
         mod = udm.get(entity)
-        num_provisioned += len(list(mod.search("(&(ucsschoolSourceUID=*)(ucsschoolRecordUID=*))")))
+        num_provisioned += len(
+            list(mod.search("(&(ucsschoolSourceUID=*)(ucsschoolRecordUID=*))"))
+        )
     return not num_provisioned or os.getenv("FORCE2RUN_SKIPPED_TEST") != "1"
 
 
