@@ -28,7 +28,12 @@ from ucsschool.kelvin.client import (
     WorkGroup as KelvinWorkGroup,
 )
 
-from .utils import DEFAULT_PASSWORD, DEFAULT_SCHOOL_AUTHORITY, DEFAULT_SCHOOL_NAME, get_access_token
+from .utils import (
+    DEFAULT_PASSWORD,
+    DEFAULT_SCHOOL_AUTHORITY,
+    DEFAULT_SCHOOL_NAME,
+    get_access_token,
+)
 
 
 @pytest.fixture(autouse=True)
@@ -60,7 +65,9 @@ def create_school(kelvin_session_obj, wait_for_dn_exists):
                 name=f"{school_authority}-{name}",
                 display_name=display_name,
                 session=session,
-                educational_servers=[f"dc-{zlib.crc32(school_authority.encode('UTF-8'))}"],
+                educational_servers=[
+                    f"dc-{zlib.crc32(school_authority.encode('UTF-8'))}"
+                ],
                 udm_properties={
                     "ucsschoolRecordUID": f"record_{school_authority}_{name}",
                     "ucsschoolSourceUID": school_authority,
@@ -95,7 +102,9 @@ async def user_cleaner(kelvin_session_obj):
             )
         ]
         if len(searched_users) == 0:
-            warnings.warn(f"The user {record}, {source} could not be found and thus was not cleaned up.")
+            warnings.warn(
+                f"The user {record}, {source} could not be found and thus was not cleaned up."
+            )
         for kelvin_user in searched_users:
             await kelvin_user.delete()
 
@@ -112,6 +121,8 @@ def create_user(kelvin_session_obj, faker, user_cleaner, wait_for_dn_exists):
         roles: List[str] = None,
         school_classes: Dict[str, List[str]] = None,
         workgroups: Dict[str, List[str]] = None,
+        legal_guardians: List[str] = None,
+        legal_wards: List[str] = None,
     ):
         if user_name is None:
             user_name = faker.pystr(1, 7)
@@ -125,6 +136,10 @@ def create_user(kelvin_session_obj, faker, user_cleaner, wait_for_dn_exists):
             workgroups = {}
         if roles is None:
             roles = ["teacher"]
+        if legal_guardians is None:
+            legal_guardians = []
+        if legal_wards is None:
+            legal_wards = []
         _user_name = (
             user_name
             if user_name == f"provisioning-{school_authority}"
@@ -146,15 +161,20 @@ def create_user(kelvin_session_obj, faker, user_cleaner, wait_for_dn_exists):
                 for school, school_classes in school_classes.items()
             },
             workgroups={
-                f"{school_authority}-{school}": workgroups for school, workgroups in workgroups.items()
+                f"{school_authority}-{school}": workgroups
+                for school, workgroups in workgroups.items()
             },
+            legal_guardians=legal_guardians,
+            legal_wards=legal_wards,
         )
         try:
             await user.save()
         except InvalidRequest as exc:
             if exc.status != 409:
                 raise
-            warnings.warn(f"recycling existing user {user.record_uid} {user.source_uid}")
+            warnings.warn(
+                f"recycling existing user {user.record_uid} {user.source_uid}"
+            )
         await wait_for_dn_exists(user.dn)
         user_cleaner(user.record_uid, user.source_uid)
         return user
@@ -260,7 +280,8 @@ async def kelvin_session_obj():
 def auth_headers(create_user, create_school):
     async def _auth_headers(school_authority: str):
         await create_user(
-            user_name=f"provisioning-{school_authority}", school_authority=school_authority
+            user_name=f"provisioning-{school_authority}",
+            school_authority=school_authority,
         )
         token = get_access_token(f"provisioning-{school_authority}")
         return {"Authorization": f"Bearer {token}"}
@@ -278,7 +299,9 @@ def wait_for_dn_exists():
         ldap = LDAPAccess(ldap_settings(), ldap_credentials())
         for i in range(timeout):
             print(f"wait for object {dn}")
-            result = await ldap.search("(objectClass=*)", search_base=dn, search_scope=SCOPE_BASE)
+            result = await ldap.search(
+                "(objectClass=*)", search_base=dn, search_scope=SCOPE_BASE
+            )
             if len(result) != 0:
                 break
             print(f"{dn} not found, retry ...")
